package com.supervision.pdfqaserver.service;

import com.supervision.pdfqaserver.dto.EREDTO;
import com.supervision.pdfqaserver.dto.DocumentDTO;
import com.supervision.pdfqaserver.dto.TableTitleDTO;
import com.supervision.pdfqaserver.dto.TruncateDTO;

import java.util.List;

/**
 * 三元组转换管道
 */
public interface TripleConversionPipeline {

    /**
     * 切分文档
     * @param documents 文档列表
     * @return
     */
    List<TruncateDTO> sliceDocuments(List<DocumentDTO> documents);


    /**
     * 实体关系抽取
     * @param truncateDTO 切分文档
     * @return
     */
    EREDTO doEre(TruncateDTO truncateDTO);

    /**
     * 分类表格是否为描述型表格
     * @param content 文档内容
     * @return true-描述型表格 false-非描述型表格
     */
    Boolean classify(String content);


    /**
     * 提取表格标题
     * @param content 文档内容
     * @return
     */
    TableTitleDTO extractTableTitle(String content);

    /**
     * 合并实体关系抽取结果
     * @param eredtoList 实体关系抽取结果列表
     * @return
     */
    List<EREDTO> mergeEreResults(List<EREDTO> eredtoList);

}
